We noticed your account was newly added by your domain administrator.

안녕하세요 {{user_name}}님, 워크스페이스 '{{workspace_name}}'에서 발송된 예산 사용 알림입니다. • 예산명: {{budget_name}} • 예산 타겟: {{budget_target}} • 예산: {{budget_amount}} ({{budget_cycle}}) • 실 사용 금액: {{actual_cost}} {{currency}} ({{usage_rate}}%) • 알림 일자: {{today_date}}
예산 현황 상세 확인하기
본 이메일은 예산 담당자 대상으로 발송되는 이메일입니다. 수신을 원치 않으시면 예산 담당자 수정 또는 워크스페이스 담당자에게 문의해주세요. 감사합니다, SpaceONE
Homepage | Blog | Help Center Copyright 2024 © MEGAZONE CLOUD Corp. All Right Reserved.